==> haskell-checkers-0.4.9.5-16-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-checkers.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: checkers
version: 0.4.9.5
id: checkers-0.4.9.5-5NzSiEywjDNH0CQL2ByQpD
key: checkers-0.4.9.5-5NzSiEywjDNH0CQL2ByQpD
license: BSD3
copyright: (c) 2008-2013 by Conal Elliott
maintainer: conal@conal.net
stability: experimental
homepage: https://github.com/conal/checkers
synopsis: Check properties on standard classes and data structures.
description:
    '\'''\''Checkers'\'''\'' wraps up the expected properties associated with various
    standard type classes as QuickCheck properties.  Also some morphism
    properties.  It also provides arbitrary instances and generator combinators
    for common data types.
    .
    &#169; 2008-2013 by Conal Elliott; BSD3 license.
category: Testing
author: Conal Elliott
exposed: True
indefinite: False
exposed-modules:
    Test.QuickCheck.Bottoms Test.QuickCheck.Checkers
    Test.QuickCheck.Classes Test.QuickCheck.Instances
    Test.QuickCheck.Instances.Array Test.QuickCheck.Instances.Char
    Test.QuickCheck.Instances.Eq Test.QuickCheck.Instances.List
    Test.QuickCheck.Instances.Maybe Test.QuickCheck.Instances.Num
    Test.QuickCheck.Instances.Ord Test.QuickCheck.Instances.Tuple
    Test.QuickCheck.Later Test.QuickCheck.Utils
hidden-modules: Control.Monad.Extensions
abi: add938a00e55aa1c4f1716f4cf09885c
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/checkers-0.4.9.5
library-dirs: /usr/lib/ghc-8.2.2/site-local/checkers-0.4.9.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/checkers-0.4.9.5
hs-libraries: HScheckers-0.4.9.5-5NzSiEywjDNH0CQL2ByQpD
depends:
    QuickCheck-2.10.1-pyTUKjDV2C3TaEubSGdV9 array-0.5.2.0 base-4.10.1.0
    random-1.1-LLUGZ7T9DqQ5vN0Jbcd0We
    semigroupoids-5.2.2-EvqgdOJ7nOu2h6meNBcBgC
abi-depends: QuickCheck-2.10.1-pyTUKjDV2C3TaEubSGdV9=77baeaa97e72dac9529ccf150f178180
             array-0.5.2.0=567646df31883e5d21d17233cc6e3caf
             base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             random-1.1-LLUGZ7T9DqQ5vN0Jbcd0We=368a9f817c8c1b290191231dd0d81d85
             semigroupoids-5.2.2-EvqgdOJ7nOu2h6meNBcBgC=bdfdbff5356805a537c879faca62e8aa
haddock-interfaces: /usr/share/doc/haskell-checkers/html/checkers.haddock
haddock-html: /usr/share/doc/haskell-checkers/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-checkers-0.4.10-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-checkers.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: checkers
version: 0.4.10
id: checkers-0.4.10-GPKiY8N80G6HQd1IF3Eb3k
key: checkers-0.4.10-GPKiY8N80G6HQd1IF3Eb3k
license: BSD3
copyright: (c) 2008-2013 by Conal Elliott
maintainer: conal@conal.net
stability: experimental
homepage: https://github.com/conal/checkers
synopsis: Check properties on standard classes and data structures.
description:
    '\'''\''Checkers'\'''\'' wraps up the expected properties associated with various
    standard type classes as QuickCheck properties.  Also some morphism
    properties.  It also provides arbitrary instances and generator combinators
    for common data types.
    .
    &#169; 2008-2013 by Conal Elliott; BSD3 license.
category: Testing
author: Conal Elliott
exposed: True
indefinite: False
exposed-modules:
    Test.QuickCheck.Bottoms Test.QuickCheck.Checkers
    Test.QuickCheck.Classes Test.QuickCheck.Instances
    Test.QuickCheck.Instances.Array Test.QuickCheck.Instances.Char
    Test.QuickCheck.Instances.Eq Test.QuickCheck.Instances.List
    Test.QuickCheck.Instances.Maybe Test.QuickCheck.Instances.Num
    Test.QuickCheck.Instances.Ord Test.QuickCheck.Instances.Tuple
    Test.QuickCheck.Later Test.QuickCheck.Utils
hidden-modules: Control.Monad.Extensions
abi: 59507296bf85bce5fc5ae6f86ccaa0e4
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/checkers-0.4.10
library-dirs: /usr/lib/ghc-8.2.2/site-local/checkers-0.4.10
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/checkers-0.4.10
hs-libraries: HScheckers-0.4.10-GPKiY8N80G6HQd1IF3Eb3k
depends:
    QuickCheck-2.10.1-pyTUKjDV2C3TaEubSGdV9 array-0.5.2.0 base-4.10.1.0
    random-1.1-LLUGZ7T9DqQ5vN0Jbcd0We
    semigroupoids-5.2.2-EvqgdOJ7nOu2h6meNBcBgC
abi-depends: QuickCheck-2.10.1-pyTUKjDV2C3TaEubSGdV9=77baeaa97e72dac9529ccf150f178180
             array-0.5.2.0=567646df31883e5d21d17233cc6e3caf
             base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             random-1.1-LLUGZ7T9DqQ5vN0Jbcd0We=368a9f817c8c1b290191231dd0d81d85
             semigroupoids-5.2.2-EvqgdOJ7nOu2h6meNBcBgC=bdfdbff5356805a537c879faca62e8aa
haddock-interfaces: /usr/share/doc/haskell-checkers/html/checkers.haddock
haddock-html: /usr/share/doc/haskell-checkers/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
